==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate.md <==
# AmazonAuroraSqlServerInstanceAlternate


```text
aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate
```

```text
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')
```



| Illustration | AmazonAuroraSqlServerInstanceAlternate | AmazonAuroraSqlServerInstanceAlternateCard | AmazonAuroraSqlServerInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate.png) | ![illustration for AmazonAuroraSqlServerInstanceAlternate](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate.Local.png) | ![illustration for AmazonAuroraSqlServerInstanceAlternateCard](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternateCard.Local.png) | ![illustration for AmazonAuroraSqlServerInstanceAlternateGroup](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternateGroup.Local.png) |




## AmazonAuroraSqlServerInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternate('AmazonAuroraSqlServerInstanceAlternate', 'Amazon Aurora Sql Server Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternate('AmazonAuroraSqlServerInstanceAlternate', 'Amazon Aurora Sql Server Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonAuroraSqlServerInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateCard('AmazonAuroraSqlServerInstanceAlternateCard', 'Amazon Aurora Sql Server Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateCard('AmazonAuroraSqlServerInstanceAlternateCard', 'Amazon Aurora Sql Server Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonAuroraSqlServerInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateGroup('AmazonAuroraSqlServerInstanceAlternateGroup', 'Amazon Aurora Sql Server Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateGroup('AmazonAuroraSqlServerInstanceAlternateGroup', 'Amazon Aurora Sql Server Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate.md <==
# AmazonAuroraSqlServerInstanceAlternate


```text
aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate
```

```text
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')
```



| Illustration | AmazonAuroraSqlServerInstanceAlternate | AmazonAuroraSqlServerInstanceAlternateCard | AmazonAuroraSqlServerInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate.png) | ![illustration for AmazonAuroraSqlServerInstanceAlternate](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate.Local.png) | ![illustration for AmazonAuroraSqlServerInstanceAlternateCard](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternateCard.Local.png) | ![illustration for AmazonAuroraSqlServerInstanceAlternateGroup](../../../aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternateGroup.Local.png) |




## AmazonAuroraSqlServerInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternate('AmazonAuroraSqlServerInstanceAlternate', 'Amazon Aurora Sql Server Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternate('AmazonAuroraSqlServerInstanceAlternate', 'Amazon Aurora Sql Server Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonAuroraSqlServerInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateCard('AmazonAuroraSqlServerInstanceAlternateCard', 'Amazon Aurora Sql Server Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateCard('AmazonAuroraSqlServerInstanceAlternateCard', 'Amazon Aurora Sql Server Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonAuroraSqlServerInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateGroup('AmazonAuroraSqlServerInstanceAlternateGroup', 'Amazon Aurora Sql Server Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraSqlServerInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraSqlServerInstanceAlternate')

' renders the element
AmazonAuroraSqlServerInstanceAlternateGroup('AmazonAuroraSqlServerInstanceAlternateGroup', 'Amazon Aurora Sql Server Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
